@@ -1,10 +1,14 @@
 use anyhow::{anyhow, Context, Result};
-use shuttle_common::{API_URL, ApiKey, DeploymentMeta, DeploymentStateMeta, SHUTTLE_PROJECT_HEADER};
-use shuttle_common::project::ProjectConfig;
+use reqwest::{Response, StatusCode};
 use reqwest_middleware::{ClientBuilder, ClientWithMiddleware};
 use reqwest_retry::{policies::ExponentialBackoff, RetryTransientMiddleware};
-use std::{fs::File, io::Read, thread::sleep, time::Duration};
-use reqwest::{Response, StatusCode};
+
+use shuttle_common::project::ProjectName;
+use shuttle_common::{
+    ApiKey, DeploymentMeta, DeploymentStateMeta, API_URL, SHUTTLE_PROJECT_HEADER,
+};
+use std::{fs::File, io::Read, time::Duration};
+use tokio::time::sleep;
 
 pub(crate) async fn auth(username: String) -> Result<ApiKey> {
     let client = get_retry_client();
@@ -25,14 +29,18 @@ pub(crate) async fn auth(username: String) -> Result<ApiKey> {
         return Ok(response_text);
     }
 
-    Err(anyhow!("{}", response_text))
+    Err(anyhow!(
+        "status: {}, body: {}",
+        response_status,
+        response_text
+    ))
 }
 
-pub(crate) async fn delete(api_key: ApiKey, project: ProjectConfig) -> Result<()> {
+pub(crate) async fn delete(api_key: &ApiKey, project: &ProjectName) -> Result<()> {
     let client = get_retry_client();
 
     let mut url = API_URL.to_string();
-    url.push_str(&format!("/projects/{}", project.name()));
+    url.push_str(&format!("/projects/{}", project));
     let res: Response = client
         .delete(url.clone())
         .basic_auth(api_key, Some(""))
@@ -47,10 +55,10 @@ pub(crate) async fn delete(api_key: ApiKey, project: ProjectConfig) -> Result<()
     Ok(())
 }
 
-pub(crate) async fn status(api_key: ApiKey, project: ProjectConfig) -> Result<()> {
+pub(crate) async fn status(api_key: &ApiKey, project: &ProjectName) -> Result<()> {
     let client = get_retry_client();
 
-    let deployment_meta = get_deployment_meta(&api_key, &project, &client).await?;
+    let deployment_meta = get_deployment_meta(api_key, project, &client).await?;
 
     println!("{}", deployment_meta);
 
@@ -59,11 +67,11 @@ pub(crate) async fn status(api_key: ApiKey, project: ProjectConfig) -> Result<()
 
 async fn get_deployment_meta(
     api_key: &ApiKey,
-    project: &ProjectConfig,
+    project: &ProjectName,
     client: &ClientWithMiddleware,
 ) -> Result<DeploymentMeta> {
     let mut url = API_URL.to_string();
-    url.push_str(&format!("/projects/{}", project.name()));
+    url.push_str(&format!("/projects/{}", project));
 
     let res: Response = client
         .get(url.clone())
@@ -84,11 +92,12 @@ fn get_retry_client() -> ClientWithMiddleware {
 
 pub(crate) async fn deploy(
     package_file: File,
-    api_key: ApiKey,
-    project: ProjectConfig,
+    api_key: &ApiKey,
+    project: &ProjectName,
 ) -> Result<()> {
     let mut url = API_URL.to_string();
-    url.push_str("/projects");
+    url.push_str("/projects/");
+    url.push_str(project.as_str());
 
     let client = get_retry_client();
 
@@ -117,9 +126,9 @@ pub(crate) async fn deploy(
     ) {
         print_log(&deployment_meta.build_logs, &mut log_pos);
 
-        sleep(Duration::from_millis(350));
+        sleep(Duration::from_millis(350)).await;
 
-        deployment_meta = get_deployment_meta(&api_key, &project, &client).await?;
+        deployment_meta = get_deployment_meta(api_key, project, &client).await?;
     }
 
     print_log(&deployment_meta.build_logs, &mut log_pos);
@@ -144,6 +153,6 @@ async fn to_api_result(res: Response) -> Result<DeploymentMeta> {
     let text = res.text().await?;
     match serde_json::from_str::<DeploymentMeta>(&text) {
         Ok(meta) => Ok(meta),
-        Err(_) => Err(anyhow!("{}", text))
+        Err(_) => Err(anyhow!("{}", text)),
     }
-}
\ No newline at end of file
+}
